# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eapi.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eapi.proto',
  package='mqpb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\neapi.proto\x12\x04mqpb\x1a\x1cgoogle/api/annotations.proto\"!\n\x12\x43ompactProofParams\x12\x0b\n\x03\x44\x45R\x18\x01 \x01(\x0c\"D\n\x14\x43ompactProofResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x10\n\x08proofDER\x18\x02 \x01(\x0c\"\x87\x01\n\x0cRevokeParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x17\n\x0f\x61ttestationHash\x18\x02 \x01(\x0c\x12\x1b\n\x13nameDeclarationHash\x18\x03 \x01(\x0c\x12\x19\n\x11revokePerspective\x18\x04 \x01(\x08\",\n\x0eRevokeResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\"P\n\x18ResolveReverseNameParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"F\n\x1aResolveReverseNameResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x0c\n\x04name\x18\x02 \x01(\t\"}\n\x1bMarkEntityInterestingParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x0e\n\x06\x65ntity\x18\x02 \x01(\x0c\x12&\n\x0e\x65ntityLocation\x18\x03 \x01(\x0b\x32\x0e.mqpb.Location\";\n\x1dMarkEntityInterestingResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\"\x85\x02\n\x1b\x43reateNameDeclarationParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\x0c\x12\'\n\x0fsubjectLocation\x18\x04 \x01(\x0b\x32\x0e.mqpb.Location\x12\x11\n\tvalidFrom\x18\x05 \x01(\x03\x12\x12\n\nvalidUntil\x18\x06 \x01(\x03\x12\x11\n\tnamespace\x18\x07 \x01(\x0c\x12)\n\x11namespaceLocation\x18\x08 \x01(\x0b\x32\x0e.mqpb.Location\x12\x11\n\tpartition\x18\t \x03(\x0c\"V\n\x1d\x43reateNameDeclarationResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x0b\n\x03\x44\x45R\x18\x02 \x01(\x0c\x12\x0c\n\x04hash\x18\x03 \x01(\x0c\"c\n\x11ResolveNameParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10topLevelAttester\x18\x03 \x01(\x0c\"\xcc\x02\n\x0fNameDeclaration\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\x0c\x12\'\n\x0fsubjectLocation\x18\x04 \x01(\x0b\x32\x0e.mqpb.Location\x12\x10\n\x08\x61ttester\x18\x05 \x01(\x0c\x12(\n\x10\x61ttesterLocation\x18\x06 \x01(\x0b\x32\x0e.mqpb.Location\x12\x11\n\tvalidFrom\x18\x07 \x01(\x03\x12\x12\n\nvalidUntil\x18\x08 \x01(\x03\x12\x11\n\tnamespace\x18\t \x01(\x0c\x12)\n\x11namespaceLocation\x18\n \x01(\x0b\x32\x0e.mqpb.Location\x12\x11\n\tpartition\x18\x0b \x03(\x0c\x12/\n\x08validity\x18\x0c \x01(\x0b\x32\x1d.mqpb.NameDeclarationValidity\"\x9c\x01\n\x13ResolveNameResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x1c\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x0c.mqpb.Entity\x12)\n\nderivation\x18\x03 \x03(\x0b\x32\x15.mqpb.NameDeclaration\x12 \n\x08location\x18\x04 \x01(\x0b\x32\x0e.mqpb.Location\"I\n\x11ResolveHashParams\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12&\n\x0bperspective\x18\x02 \x01(\x0b\x32\x11.mqpb.Perspective\"\x99\x01\n\x13ResolveHashResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12 \n\x08location\x18\x02 \x01(\x0b\x32\x0e.mqpb.Location\x12\x1c\n\x06\x65ntity\x18\x03 \x01(\x0b\x32\x0c.mqpb.Entity\x12&\n\x0b\x61ttestation\x18\x04 \x01(\x0b\x32\x11.mqpb.Attestation\"H\n\rInspectParams\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x11\n\tproverKey\x18\x02 \x01(\x0c\x12\x13\n\x0bverifierKey\x18\x03 \x01(\x0c\"s\n\x0fInspectResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x1c\n\x06\x65ntity\x18\x02 \x01(\x0b\x32\x0c.mqpb.Entity\x12&\n\x0b\x61ttestation\x18\x03 \x01(\x0b\x32\x11.mqpb.Attestation\"\x15\n\x13ListLocationsParams\"\xc3\x01\n\x15ListLocationsResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12G\n\x0e\x61gentLocations\x18\x02 \x03(\x0b\x32/.mqpb.ListLocationsResponse.AgentLocationsEntry\x1a\x45\n\x13\x41gentLocationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.mqpb.Location:\x02\x38\x01\"\x81\x01\n\x12\x43reateEntityParams\x12\x11\n\tvalidFrom\x18\x01 \x01(\x03\x12\x12\n\nvalidUntil\x18\x02 \x01(\x03\x12*\n\x12revocationLocation\x18\x03 \x01(\x0b\x32\x0e.mqpb.Location\x12\x18\n\x10SecretPassphrase\x18\x04 \x01(\t\"f\n\x14\x43reateEntityResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x11\n\tPublicDER\x18\x02 \x01(\x0c\x12\x11\n\tSecretDER\x18\x03 \x01(\x0c\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\"e\n\x06\x45ntity\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x11\n\tvalidFrom\x18\x02 \x01(\x03\x12\x12\n\nvalidUntil\x18\x03 \x01(\x03\x12&\n\x08validity\x18\x04 \x01(\x0b\x32\x14.mqpb.EntityValidity\"\xe9\x01\n\x17\x43reateAttestationParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x12\n\nbodyScheme\x18\x02 \x01(\t\x12\x13\n\x0bsubjectHash\x18\x03 \x01(\x0c\x12\'\n\x0fsubjectLocation\x18\x04 \x01(\x0b\x32\x0e.mqpb.Location\x12\x11\n\tvalidFrom\x18\x05 \x01(\x03\x12\x12\n\nvalidUntil\x18\x06 \x01(\x03\x12\x1c\n\x06policy\x18\x07 \x01(\x0b\x32\x0c.mqpb.Policy\x12\x0f\n\x07publish\x18\x08 \x01(\x08\"F\n\x1cResyncPerspectiveGraphParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\"<\n\x1eResyncPerspectiveGraphResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\"4\n\nSyncParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\"\x84\x02\n\x14\x45ncryptMessageParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x13\n\x0bsubjectHash\x18\x03 \x01(\x0c\x12\'\n\x0fsubjectLocation\x18\x04 \x01(\x0b\x32\x0e.mqpb.Location\x12\x11\n\tnamespace\x18\x05 \x01(\x0c\x12)\n\x11namespaceLocation\x18\x06 \x01(\x0b\x32\x0e.mqpb.Location\x12\x10\n\x08resource\x18\x07 \x01(\t\x12\x11\n\tvalidFrom\x18\x08 \x01(\x03\x12\x12\n\nvalidUntil\x18\t \x01(\x03\"H\n\x16\x45ncryptMessageResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x12\n\nciphertext\x18\x02 \x01(\x0c\"R\n\x14\x44\x65\x63ryptMessageParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x12\n\nciphertext\x18\x02 \x01(\x0c\"E\n\x16\x44\x65\x63ryptMessageResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"\xec\x01\n\x0cSyncResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12<\n\rstorageStatus\x18\x02 \x03(\x0b\x32%.mqpb.SyncResponse.StorageStatusEntry\x12\x19\n\x11totalSyncRequests\x18\x03 \x01(\x03\x12\x16\n\x0e\x63ompletedSyncs\x18\x04 \x01(\x03\x1aO\n\x12StorageStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.mqpb.StorageDriverStatus:\x02\x38\x01\"\x8a\x01\n\x13StorageDriverStatus\x12\x13\n\x0boperational\x18\x01 \x01(\x08\x12\x31\n\x04info\x18\x02 \x03(\x0b\x32#.mqpb.StorageDriverStatus.InfoEntry\x1a+\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x19\x43reateAttestationResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x0b\n\x03\x44\x45R\x18\x02 \x01(\x0c\x12\x13\n\x0bverifierKey\x18\x03 \x01(\x0c\x12\x11\n\tproverKey\x18\x04 \x01(\x0c\x12\x0c\n\x04hash\x18\x05 \x01(\x0c\"D\n\x13PublishEntityParams\x12\x0b\n\x03\x44\x45R\x18\x01 \x01(\x0c\x12 \n\x08location\x18\x02 \x01(\x0b\x32\x0e.mqpb.Location\"A\n\x15PublishEntityResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"\'\n\x18PublishAttestationParams\x12\x0b\n\x03\x44\x45R\x18\x01 \x01(\x0c\"F\n\x1aPublishAttestationResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"^\n\x14\x41\x64\x64\x41ttestationParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x0b\n\x03\x44\x45R\x18\x02 \x01(\x0c\x12\x11\n\tproverKey\x18\x03 \x01(\x0c\"4\n\x16\x41\x64\x64\x41ttestationResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\"h\n\x18LookupAttestationsParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x12\n\nfromEntity\x18\x02 \x01(\x0c\x12\x10\n\x08toEntity\x18\x03 \x01(\x0c\"\\\n\x1aLookupAttestationsResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\"\n\x07results\x18\x02 \x03(\x0b\x32\x11.mqpb.Attestation\"&\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"Y\n\x0bPerspective\x12(\n\x0c\x65ntitySecret\x18\x01 \x01(\x0b\x32\x12.mqpb.EntitySecret\x12 \n\x08location\x18\x02 \x01(\x0b\x32\x0e.mqpb.Location\"I\n\x08Location\x12&\n\x0blocationURI\x18\x01 \x01(\x0b\x32\x11.mqpb.LocationURI\x12\x15\n\ragentLocation\x18\x02 \x01(\t\"+\n\x0bLocationURI\x12\x0b\n\x03URI\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\"/\n\x0c\x45ntitySecret\x12\x0b\n\x03\x44\x45R\x18\x01 \x01(\x0c\x12\x12\n\npassphrase\x18\x02 \x01(\x0c\"\xf3\x01\n\x0b\x41ttestation\x12\x0b\n\x03\x44\x45R\x18\x01 \x01(\x0c\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\x12#\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x15.mqpb.AttestationBody\x12\x13\n\x0bverifierKey\x18\x04 \x01(\x0c\x12\x11\n\tproverKey\x18\x05 \x01(\x0c\x12\x13\n\x0bsubjectHash\x18\x06 \x01(\x0c\x12\'\n\x0fsubjectLocation\x18\x07 \x01(\x0b\x32\x0e.mqpb.Location\x12+\n\x08validity\x18\x08 \x01(\x0b\x32\x19.mqpb.AttestationValidity\x12\x11\n\tpartition\x18\t \x03(\x0c\"\xae\x01\n\x0f\x41ttestationBody\x12\x16\n\x0e\x44\x65\x63odedBodyDER\x18\x01 \x01(\x0c\x12\x14\n\x0c\x61ttesterHash\x18\x02 \x01(\x0c\x12(\n\x10\x61ttesterLocation\x18\x03 \x01(\x0b\x32\x0e.mqpb.Location\x12\x1c\n\x06policy\x18\x04 \x01(\x0b\x32\x0c.mqpb.Policy\x12\x11\n\tvalidFrom\x18\x05 \x01(\x03\x12\x12\n\nvalidUntil\x18\x06 \x01(\x03\"\xbd\x01\n\x13\x41ttestationValidity\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0f\n\x07revoked\x18\x02 \x01(\x08\x12\x0f\n\x07\x65xpired\x18\x03 \x01(\x08\x12\x11\n\tmalformed\x18\x04 \x01(\x08\x12\x14\n\x0cnotDecrypted\x18\x05 \x01(\x08\x12\x12\n\nsrcInvalid\x18\x06 \x01(\x08\x12\x12\n\ndstInvalid\x18\x07 \x01(\x08\x12\x0f\n\x07message\x18\x08 \x01(\t\x12\x13\n\x0bnotValidYet\x18\t \x01(\x08\"z\n\x0e\x45ntityValidity\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0f\n\x07revoked\x18\x02 \x01(\x08\x12\x0f\n\x07\x65xpired\x18\x03 \x01(\x08\x12\x11\n\tmalformed\x18\x04 \x01(\x08\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x13\n\x0bnotValidYet\x18\x06 \x01(\x08\"\x83\x01\n\x17NameDeclarationValidity\x12\r\n\x05valid\x18\x01 \x01(\x08\x12\x0f\n\x07revoked\x18\x02 \x01(\x08\x12\x0f\n\x07\x65xpired\x18\x03 \x01(\x08\x12\x11\n\tmalformed\x18\x04 \x01(\x08\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x13\n\x0bnotValidYet\x18\x06 \x01(\x08\"b\n\x06Policy\x12\x30\n\x10trustLevelPolicy\x18\x01 \x01(\x0b\x32\x16.mqpb.TrustLevelPolicy\x12&\n\x0brTreePolicy\x18\x02 \x01(\x0b\x32\x11.mqpb.RTreePolicy\"!\n\x10TrustLevelPolicy\x12\r\n\x05trust\x18\x01 \x01(\x05\"}\n\x0bRTreePolicy\x12\x11\n\tnamespace\x18\x01 \x01(\x0c\x12\x14\n\x0cindirections\x18\x02 \x01(\r\x12.\n\nstatements\x18\x03 \x03(\x0b\x32\x1a.mqpb.RTreePolicyStatement\x12\x15\n\rvisibilityURI\x18\x04 \x03(\x0c\"T\n\x14RTreePolicyStatement\x12\x15\n\rpermissionSet\x18\x01 \x01(\x0c\x12\x13\n\x0bpermissions\x18\x02 \x03(\t\x12\x10\n\x08resource\x18\x03 \x01(\t\"\xac\x01\n\x15\x42uildRTreeProofParams\x12&\n\x0bperspective\x18\x01 \x01(\x0b\x32\x11.mqpb.Perspective\x12\x13\n\x0bsubjectHash\x18\x02 \x01(\x0c\x12\x11\n\tnamespace\x18\x03 \x01(\x0c\x12.\n\nstatements\x18\x04 \x03(\x0b\x32\x1a.mqpb.RTreePolicyStatement\x12\x13\n\x0bresyncFirst\x18\x05 \x01(\x08\"d\n\x17\x42uildRTreeProofResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x1b\n\x06result\x18\x02 \x01(\x0b\x32\x0b.mqpb.Proof\x12\x10\n\x08proofDER\x18\x03 \x01(\x0c\"U\n\x11VerifyProofParams\x12\x10\n\x08proofDER\x18\x01 \x01(\x0c\x12.\n\x13requiredRTreePolicy\x18\x02 \x01(\x0b\x32\x11.mqpb.RTreePolicy\"N\n\x13VerifyProofResponse\x12\x1a\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0b.mqpb.Error\x12\x1b\n\x06result\x18\x02 \x01(\x0b\x32\x0b.mqpb.Proof\"\xb4\x01\n\x05Proof\x12#\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x11.mqpb.Attestation\x12\x1e\n\x05paths\x18\x02 \x03(\x0b\x32\x0f.mqpb.ProofPath\x12\x1c\n\x06policy\x18\x03 \x01(\x0b\x32\x0c.mqpb.Policy\x12\x0e\n\x06\x65xpiry\x18\x04 \x01(\x03\x12\x0f\n\x07subject\x18\x05 \x01(\x0c\x12\'\n\x0fsubjectLocation\x18\x06 \x01(\x0b\x32\x0e.mqpb.Location\"\x1d\n\tProofPath\x12\x10\n\x08\x65lements\x18\x01 \x03(\x05\x32\x92\x12\n\x04WAVE\x12\x61\n\x0c\x43reateEntity\x12\x18.mqpb.CreateEntityParams\x1a\x1a.mqpb.CreateEntityResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/CreateEntity:\x01*\x12u\n\x11\x43reateAttestation\x12\x1d.mqpb.CreateAttestationParams\x1a\x1f.mqpb.CreateAttestationResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/CreateAttestation:\x01*\x12\x65\n\rPublishEntity\x12\x19.mqpb.PublishEntityParams\x1a\x1b.mqpb.PublishEntityResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/PublishEntity:\x01*\x12y\n\x12PublishAttestation\x12\x1e.mqpb.PublishAttestationParams\x1a .mqpb.PublishAttestationResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v1/PublishAttestation:\x01*\x12i\n\x0e\x41\x64\x64\x41ttestation\x12\x1a.mqpb.AddAttestationParams\x1a\x1c.mqpb.AddAttestationResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/AddAttestation:\x01*\x12x\n\x12LookupAttestations\x12\x1e.mqpb.LookupAttestationsParams\x1a .mqpb.LookupAttestationsResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/LookupAttestation:\x01*\x12\x89\x01\n\x16ResyncPerspectiveGraph\x12\".mqpb.ResyncPerspectiveGraphParams\x1a$.mqpb.ResyncPerspectiveGraphResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/ResyncPerspectiveGraph:\x01*\x12M\n\nSyncStatus\x12\x10.mqpb.SyncParams\x1a\x12.mqpb.SyncResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/SyncStatus:\x01*\x12=\n\x13WaitForSyncComplete\x12\x10.mqpb.SyncParams\x1a\x12.mqpb.SyncResponse0\x01\x12m\n\x0f\x42uildRTreeProof\x12\x1b.mqpb.BuildRTreeProofParams\x1a\x1d.mqpb.BuildRTreeProofResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/BuildRTreeProof:\x01*\x12]\n\x0bVerifyProof\x12\x17.mqpb.VerifyProofParams\x1a\x19.mqpb.VerifyProofResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/VerifyProof:\x01*\x12\x65\n\rListLocations\x12\x19.mqpb.ListLocationsParams\x1a\x1b.mqpb.ListLocationsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/ListLocations:\x01*\x12M\n\x07Inspect\x12\x13.mqpb.InspectParams\x1a\x15.mqpb.InspectResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/Inspect:\x01*\x12]\n\x0bResolveHash\x12\x17.mqpb.ResolveHashParams\x1a\x19.mqpb.ResolveHashResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/ResolveHash:\x01*\x12i\n\x0e\x45ncryptMessage\x12\x1a.mqpb.EncryptMessageParams\x1a\x1c.mqpb.EncryptMessageResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/EncryptMessage:\x01*\x12i\n\x0e\x44\x65\x63ryptMessage\x12\x1a.mqpb.DecryptMessageParams\x1a\x1c.mqpb.DecryptMessageResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/DecryptMessage:\x01*\x12\x85\x01\n\x15\x43reateNameDeclaration\x12!.mqpb.CreateNameDeclarationParams\x1a#.mqpb.CreateNameDeclarationResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/CreateNameDeclaration:\x01*\x12]\n\x0bResolveName\x12\x17.mqpb.ResolveNameParams\x1a\x19.mqpb.ResolveNameResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/ResolveName:\x01*\x12\x85\x01\n\x15MarkEntityInteresting\x12!.mqpb.MarkEntityInterestingParams\x1a#.mqpb.MarkEntityInterestingResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/MarkEntityInteresting:\x01*\x12y\n\x12ResolveReverseName\x12\x1e.mqpb.ResolveReverseNameParams\x1a .mqpb.ResolveReverseNameResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v1/ResolveReverseName:\x01*\x12I\n\x06Revoke\x12\x12.mqpb.RevokeParams\x1a\x14.mqpb.RevokeResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v1/Revoke:\x01*\x12\x61\n\x0c\x43ompactProof\x12\x18.mqpb.CompactProofParams\x1a\x1a.mqpb.CompactProofResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/CompactProof:\x01*b\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_COMPACTPROOFPARAMS = _descriptor.Descriptor(
  name='CompactProofParams',
  full_name='mqpb.CompactProofParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='DER', full_name='mqpb.CompactProofParams.DER', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=83,
)


_COMPACTPROOFRESPONSE = _descriptor.Descriptor(
  name='CompactProofResponse',
  full_name='mqpb.CompactProofResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.CompactProofResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proofDER', full_name='mqpb.CompactProofResponse.proofDER', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=153,
)


_REVOKEPARAMS = _descriptor.Descriptor(
  name='RevokeParams',
  full_name='mqpb.RevokeParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.RevokeParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attestationHash', full_name='mqpb.RevokeParams.attestationHash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nameDeclarationHash', full_name='mqpb.RevokeParams.nameDeclarationHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revokePerspective', full_name='mqpb.RevokeParams.revokePerspective', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=291,
)


_REVOKERESPONSE = _descriptor.Descriptor(
  name='RevokeResponse',
  full_name='mqpb.RevokeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.RevokeResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=337,
)


_RESOLVEREVERSENAMEPARAMS = _descriptor.Descriptor(
  name='ResolveReverseNameParams',
  full_name='mqpb.ResolveReverseNameParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.ResolveReverseNameParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.ResolveReverseNameParams.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=419,
)


_RESOLVEREVERSENAMERESPONSE = _descriptor.Descriptor(
  name='ResolveReverseNameResponse',
  full_name='mqpb.ResolveReverseNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.ResolveReverseNameResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='mqpb.ResolveReverseNameResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=491,
)


_MARKENTITYINTERESTINGPARAMS = _descriptor.Descriptor(
  name='MarkEntityInterestingParams',
  full_name='mqpb.MarkEntityInterestingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.MarkEntityInterestingParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='mqpb.MarkEntityInterestingParams.entity', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entityLocation', full_name='mqpb.MarkEntityInterestingParams.entityLocation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=618,
)


_MARKENTITYINTERESTINGRESPONSE = _descriptor.Descriptor(
  name='MarkEntityInterestingResponse',
  full_name='mqpb.MarkEntityInterestingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.MarkEntityInterestingResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=620,
  serialized_end=679,
)


_CREATENAMEDECLARATIONPARAMS = _descriptor.Descriptor(
  name='CreateNameDeclarationParams',
  full_name='mqpb.CreateNameDeclarationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.CreateNameDeclarationParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='mqpb.CreateNameDeclarationParams.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='mqpb.CreateNameDeclarationParams.subject', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectLocation', full_name='mqpb.CreateNameDeclarationParams.subjectLocation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validFrom', full_name='mqpb.CreateNameDeclarationParams.validFrom', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validUntil', full_name='mqpb.CreateNameDeclarationParams.validUntil', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.CreateNameDeclarationParams.namespace', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespaceLocation', full_name='mqpb.CreateNameDeclarationParams.namespaceLocation', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition', full_name='mqpb.CreateNameDeclarationParams.partition', index=8,
      number=9, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=943,
)


_CREATENAMEDECLARATIONRESPONSE = _descriptor.Descriptor(
  name='CreateNameDeclarationResponse',
  full_name='mqpb.CreateNameDeclarationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.CreateNameDeclarationResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='DER', full_name='mqpb.CreateNameDeclarationResponse.DER', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.CreateNameDeclarationResponse.hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=945,
  serialized_end=1031,
)


_RESOLVENAMEPARAMS = _descriptor.Descriptor(
  name='ResolveNameParams',
  full_name='mqpb.ResolveNameParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.ResolveNameParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='mqpb.ResolveNameParams.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topLevelAttester', full_name='mqpb.ResolveNameParams.topLevelAttester', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1033,
  serialized_end=1132,
)


_NAMEDECLARATION = _descriptor.Descriptor(
  name='NameDeclaration',
  full_name='mqpb.NameDeclaration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.NameDeclaration.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='mqpb.NameDeclaration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='mqpb.NameDeclaration.subject', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectLocation', full_name='mqpb.NameDeclaration.subjectLocation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attester', full_name='mqpb.NameDeclaration.attester', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attesterLocation', full_name='mqpb.NameDeclaration.attesterLocation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validFrom', full_name='mqpb.NameDeclaration.validFrom', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validUntil', full_name='mqpb.NameDeclaration.validUntil', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.NameDeclaration.namespace', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespaceLocation', full_name='mqpb.NameDeclaration.namespaceLocation', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition', full_name='mqpb.NameDeclaration.partition', index=10,
      number=11, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validity', full_name='mqpb.NameDeclaration.validity', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1467,
)


_RESOLVENAMERESPONSE = _descriptor.Descriptor(
  name='ResolveNameResponse',
  full_name='mqpb.ResolveNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.ResolveNameResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='mqpb.ResolveNameResponse.entity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='derivation', full_name='mqpb.ResolveNameResponse.derivation', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='mqpb.ResolveNameResponse.location', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1470,
  serialized_end=1626,
)


_RESOLVEHASHPARAMS = _descriptor.Descriptor(
  name='ResolveHashParams',
  full_name='mqpb.ResolveHashParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.ResolveHashParams.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.ResolveHashParams.perspective', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1628,
  serialized_end=1701,
)


_RESOLVEHASHRESPONSE = _descriptor.Descriptor(
  name='ResolveHashResponse',
  full_name='mqpb.ResolveHashResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.ResolveHashResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='mqpb.ResolveHashResponse.location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='mqpb.ResolveHashResponse.entity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attestation', full_name='mqpb.ResolveHashResponse.attestation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1704,
  serialized_end=1857,
)


_INSPECTPARAMS = _descriptor.Descriptor(
  name='InspectParams',
  full_name='mqpb.InspectParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='mqpb.InspectParams.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proverKey', full_name='mqpb.InspectParams.proverKey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verifierKey', full_name='mqpb.InspectParams.verifierKey', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1859,
  serialized_end=1931,
)


_INSPECTRESPONSE = _descriptor.Descriptor(
  name='InspectResponse',
  full_name='mqpb.InspectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.InspectResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='mqpb.InspectResponse.entity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attestation', full_name='mqpb.InspectResponse.attestation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1933,
  serialized_end=2048,
)


_LISTLOCATIONSPARAMS = _descriptor.Descriptor(
  name='ListLocationsParams',
  full_name='mqpb.ListLocationsParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2050,
  serialized_end=2071,
)


_LISTLOCATIONSRESPONSE_AGENTLOCATIONSENTRY = _descriptor.Descriptor(
  name='AgentLocationsEntry',
  full_name='mqpb.ListLocationsResponse.AgentLocationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mqpb.ListLocationsResponse.AgentLocationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mqpb.ListLocationsResponse.AgentLocationsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2200,
  serialized_end=2269,
)

_LISTLOCATIONSRESPONSE = _descriptor.Descriptor(
  name='ListLocationsResponse',
  full_name='mqpb.ListLocationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.ListLocationsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agentLocations', full_name='mqpb.ListLocationsResponse.agentLocations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LISTLOCATIONSRESPONSE_AGENTLOCATIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2074,
  serialized_end=2269,
)


_CREATEENTITYPARAMS = _descriptor.Descriptor(
  name='CreateEntityParams',
  full_name='mqpb.CreateEntityParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validFrom', full_name='mqpb.CreateEntityParams.validFrom', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validUntil', full_name='mqpb.CreateEntityParams.validUntil', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revocationLocation', full_name='mqpb.CreateEntityParams.revocationLocation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SecretPassphrase', full_name='mqpb.CreateEntityParams.SecretPassphrase', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2272,
  serialized_end=2401,
)


_CREATEENTITYRESPONSE = _descriptor.Descriptor(
  name='CreateEntityResponse',
  full_name='mqpb.CreateEntityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.CreateEntityResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='PublicDER', full_name='mqpb.CreateEntityResponse.PublicDER', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SecretDER', full_name='mqpb.CreateEntityResponse.SecretDER', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.CreateEntityResponse.hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2403,
  serialized_end=2505,
)


_ENTITY = _descriptor.Descriptor(
  name='Entity',
  full_name='mqpb.Entity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.Entity.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validFrom', full_name='mqpb.Entity.validFrom', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validUntil', full_name='mqpb.Entity.validUntil', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validity', full_name='mqpb.Entity.validity', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2507,
  serialized_end=2608,
)


_CREATEATTESTATIONPARAMS = _descriptor.Descriptor(
  name='CreateAttestationParams',
  full_name='mqpb.CreateAttestationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.CreateAttestationParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bodyScheme', full_name='mqpb.CreateAttestationParams.bodyScheme', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectHash', full_name='mqpb.CreateAttestationParams.subjectHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectLocation', full_name='mqpb.CreateAttestationParams.subjectLocation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validFrom', full_name='mqpb.CreateAttestationParams.validFrom', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validUntil', full_name='mqpb.CreateAttestationParams.validUntil', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy', full_name='mqpb.CreateAttestationParams.policy', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='publish', full_name='mqpb.CreateAttestationParams.publish', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2611,
  serialized_end=2844,
)


_RESYNCPERSPECTIVEGRAPHPARAMS = _descriptor.Descriptor(
  name='ResyncPerspectiveGraphParams',
  full_name='mqpb.ResyncPerspectiveGraphParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.ResyncPerspectiveGraphParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2846,
  serialized_end=2916,
)


_RESYNCPERSPECTIVEGRAPHRESPONSE = _descriptor.Descriptor(
  name='ResyncPerspectiveGraphResponse',
  full_name='mqpb.ResyncPerspectiveGraphResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.ResyncPerspectiveGraphResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2918,
  serialized_end=2978,
)


_SYNCPARAMS = _descriptor.Descriptor(
  name='SyncParams',
  full_name='mqpb.SyncParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.SyncParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2980,
  serialized_end=3032,
)


_ENCRYPTMESSAGEPARAMS = _descriptor.Descriptor(
  name='EncryptMessageParams',
  full_name='mqpb.EncryptMessageParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.EncryptMessageParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='mqpb.EncryptMessageParams.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectHash', full_name='mqpb.EncryptMessageParams.subjectHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectLocation', full_name='mqpb.EncryptMessageParams.subjectLocation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.EncryptMessageParams.namespace', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespaceLocation', full_name='mqpb.EncryptMessageParams.namespaceLocation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource', full_name='mqpb.EncryptMessageParams.resource', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validFrom', full_name='mqpb.EncryptMessageParams.validFrom', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validUntil', full_name='mqpb.EncryptMessageParams.validUntil', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3035,
  serialized_end=3295,
)


_ENCRYPTMESSAGERESPONSE = _descriptor.Descriptor(
  name='EncryptMessageResponse',
  full_name='mqpb.EncryptMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.EncryptMessageResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='mqpb.EncryptMessageResponse.ciphertext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3297,
  serialized_end=3369,
)


_DECRYPTMESSAGEPARAMS = _descriptor.Descriptor(
  name='DecryptMessageParams',
  full_name='mqpb.DecryptMessageParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.DecryptMessageParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ciphertext', full_name='mqpb.DecryptMessageParams.ciphertext', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3371,
  serialized_end=3453,
)


_DECRYPTMESSAGERESPONSE = _descriptor.Descriptor(
  name='DecryptMessageResponse',
  full_name='mqpb.DecryptMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.DecryptMessageResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='mqpb.DecryptMessageResponse.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3455,
  serialized_end=3524,
)


_SYNCRESPONSE_STORAGESTATUSENTRY = _descriptor.Descriptor(
  name='StorageStatusEntry',
  full_name='mqpb.SyncResponse.StorageStatusEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mqpb.SyncResponse.StorageStatusEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mqpb.SyncResponse.StorageStatusEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3684,
  serialized_end=3763,
)

_SYNCRESPONSE = _descriptor.Descriptor(
  name='SyncResponse',
  full_name='mqpb.SyncResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.SyncResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storageStatus', full_name='mqpb.SyncResponse.storageStatus', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSyncRequests', full_name='mqpb.SyncResponse.totalSyncRequests', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='completedSyncs', full_name='mqpb.SyncResponse.completedSyncs', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SYNCRESPONSE_STORAGESTATUSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3527,
  serialized_end=3763,
)


_STORAGEDRIVERSTATUS_INFOENTRY = _descriptor.Descriptor(
  name='InfoEntry',
  full_name='mqpb.StorageDriverStatus.InfoEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mqpb.StorageDriverStatus.InfoEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mqpb.StorageDriverStatus.InfoEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3861,
  serialized_end=3904,
)

_STORAGEDRIVERSTATUS = _descriptor.Descriptor(
  name='StorageDriverStatus',
  full_name='mqpb.StorageDriverStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operational', full_name='mqpb.StorageDriverStatus.operational', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='mqpb.StorageDriverStatus.info', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STORAGEDRIVERSTATUS_INFOENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3766,
  serialized_end=3904,
)


_CREATEATTESTATIONRESPONSE = _descriptor.Descriptor(
  name='CreateAttestationResponse',
  full_name='mqpb.CreateAttestationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.CreateAttestationResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='DER', full_name='mqpb.CreateAttestationResponse.DER', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verifierKey', full_name='mqpb.CreateAttestationResponse.verifierKey', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proverKey', full_name='mqpb.CreateAttestationResponse.proverKey', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.CreateAttestationResponse.hash', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3906,
  serialized_end=4028,
)


_PUBLISHENTITYPARAMS = _descriptor.Descriptor(
  name='PublishEntityParams',
  full_name='mqpb.PublishEntityParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='DER', full_name='mqpb.PublishEntityParams.DER', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='mqpb.PublishEntityParams.location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4030,
  serialized_end=4098,
)


_PUBLISHENTITYRESPONSE = _descriptor.Descriptor(
  name='PublishEntityResponse',
  full_name='mqpb.PublishEntityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.PublishEntityResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.PublishEntityResponse.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4100,
  serialized_end=4165,
)


_PUBLISHATTESTATIONPARAMS = _descriptor.Descriptor(
  name='PublishAttestationParams',
  full_name='mqpb.PublishAttestationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='DER', full_name='mqpb.PublishAttestationParams.DER', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4167,
  serialized_end=4206,
)


_PUBLISHATTESTATIONRESPONSE = _descriptor.Descriptor(
  name='PublishAttestationResponse',
  full_name='mqpb.PublishAttestationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.PublishAttestationResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.PublishAttestationResponse.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4208,
  serialized_end=4278,
)


_ADDATTESTATIONPARAMS = _descriptor.Descriptor(
  name='AddAttestationParams',
  full_name='mqpb.AddAttestationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.AddAttestationParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='DER', full_name='mqpb.AddAttestationParams.DER', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proverKey', full_name='mqpb.AddAttestationParams.proverKey', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4280,
  serialized_end=4374,
)


_ADDATTESTATIONRESPONSE = _descriptor.Descriptor(
  name='AddAttestationResponse',
  full_name='mqpb.AddAttestationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.AddAttestationResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4376,
  serialized_end=4428,
)


_LOOKUPATTESTATIONSPARAMS = _descriptor.Descriptor(
  name='LookupAttestationsParams',
  full_name='mqpb.LookupAttestationsParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.LookupAttestationsParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromEntity', full_name='mqpb.LookupAttestationsParams.fromEntity', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='toEntity', full_name='mqpb.LookupAttestationsParams.toEntity', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4430,
  serialized_end=4534,
)


_LOOKUPATTESTATIONSRESPONSE = _descriptor.Descriptor(
  name='LookupAttestationsResponse',
  full_name='mqpb.LookupAttestationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.LookupAttestationsResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='mqpb.LookupAttestationsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4536,
  serialized_end=4628,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='mqpb.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='mqpb.Error.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='mqpb.Error.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4630,
  serialized_end=4668,
)


_PERSPECTIVE = _descriptor.Descriptor(
  name='Perspective',
  full_name='mqpb.Perspective',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entitySecret', full_name='mqpb.Perspective.entitySecret', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='mqpb.Perspective.location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4670,
  serialized_end=4759,
)


_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='mqpb.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='locationURI', full_name='mqpb.Location.locationURI', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agentLocation', full_name='mqpb.Location.agentLocation', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4761,
  serialized_end=4834,
)


_LOCATIONURI = _descriptor.Descriptor(
  name='LocationURI',
  full_name='mqpb.LocationURI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='URI', full_name='mqpb.LocationURI.URI', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='mqpb.LocationURI.version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4836,
  serialized_end=4879,
)


_ENTITYSECRET = _descriptor.Descriptor(
  name='EntitySecret',
  full_name='mqpb.EntitySecret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='DER', full_name='mqpb.EntitySecret.DER', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='passphrase', full_name='mqpb.EntitySecret.passphrase', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4881,
  serialized_end=4928,
)


_ATTESTATION = _descriptor.Descriptor(
  name='Attestation',
  full_name='mqpb.Attestation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='DER', full_name='mqpb.Attestation.DER', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='mqpb.Attestation.hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='mqpb.Attestation.body', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verifierKey', full_name='mqpb.Attestation.verifierKey', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proverKey', full_name='mqpb.Attestation.proverKey', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectHash', full_name='mqpb.Attestation.subjectHash', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectLocation', full_name='mqpb.Attestation.subjectLocation', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validity', full_name='mqpb.Attestation.validity', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partition', full_name='mqpb.Attestation.partition', index=8,
      number=9, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4931,
  serialized_end=5174,
)


_ATTESTATIONBODY = _descriptor.Descriptor(
  name='AttestationBody',
  full_name='mqpb.AttestationBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='DecodedBodyDER', full_name='mqpb.AttestationBody.DecodedBodyDER', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attesterHash', full_name='mqpb.AttestationBody.attesterHash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attesterLocation', full_name='mqpb.AttestationBody.attesterLocation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy', full_name='mqpb.AttestationBody.policy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validFrom', full_name='mqpb.AttestationBody.validFrom', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validUntil', full_name='mqpb.AttestationBody.validUntil', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5177,
  serialized_end=5351,
)


_ATTESTATIONVALIDITY = _descriptor.Descriptor(
  name='AttestationValidity',
  full_name='mqpb.AttestationValidity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='mqpb.AttestationValidity.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revoked', full_name='mqpb.AttestationValidity.revoked', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expired', full_name='mqpb.AttestationValidity.expired', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='malformed', full_name='mqpb.AttestationValidity.malformed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notDecrypted', full_name='mqpb.AttestationValidity.notDecrypted', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='srcInvalid', full_name='mqpb.AttestationValidity.srcInvalid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dstInvalid', full_name='mqpb.AttestationValidity.dstInvalid', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='mqpb.AttestationValidity.message', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notValidYet', full_name='mqpb.AttestationValidity.notValidYet', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5354,
  serialized_end=5543,
)


_ENTITYVALIDITY = _descriptor.Descriptor(
  name='EntityValidity',
  full_name='mqpb.EntityValidity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='mqpb.EntityValidity.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revoked', full_name='mqpb.EntityValidity.revoked', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expired', full_name='mqpb.EntityValidity.expired', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='malformed', full_name='mqpb.EntityValidity.malformed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='mqpb.EntityValidity.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notValidYet', full_name='mqpb.EntityValidity.notValidYet', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5545,
  serialized_end=5667,
)


_NAMEDECLARATIONVALIDITY = _descriptor.Descriptor(
  name='NameDeclarationValidity',
  full_name='mqpb.NameDeclarationValidity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='mqpb.NameDeclarationValidity.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revoked', full_name='mqpb.NameDeclarationValidity.revoked', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expired', full_name='mqpb.NameDeclarationValidity.expired', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='malformed', full_name='mqpb.NameDeclarationValidity.malformed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='mqpb.NameDeclarationValidity.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notValidYet', full_name='mqpb.NameDeclarationValidity.notValidYet', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5670,
  serialized_end=5801,
)


_POLICY = _descriptor.Descriptor(
  name='Policy',
  full_name='mqpb.Policy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trustLevelPolicy', full_name='mqpb.Policy.trustLevelPolicy', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rTreePolicy', full_name='mqpb.Policy.rTreePolicy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5803,
  serialized_end=5901,
)


_TRUSTLEVELPOLICY = _descriptor.Descriptor(
  name='TrustLevelPolicy',
  full_name='mqpb.TrustLevelPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trust', full_name='mqpb.TrustLevelPolicy.trust', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5903,
  serialized_end=5936,
)


_RTREEPOLICY = _descriptor.Descriptor(
  name='RTreePolicy',
  full_name='mqpb.RTreePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.RTreePolicy.namespace', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indirections', full_name='mqpb.RTreePolicy.indirections', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statements', full_name='mqpb.RTreePolicy.statements', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='visibilityURI', full_name='mqpb.RTreePolicy.visibilityURI', index=3,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5938,
  serialized_end=6063,
)


_RTREEPOLICYSTATEMENT = _descriptor.Descriptor(
  name='RTreePolicyStatement',
  full_name='mqpb.RTreePolicyStatement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissionSet', full_name='mqpb.RTreePolicyStatement.permissionSet', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='mqpb.RTreePolicyStatement.permissions', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource', full_name='mqpb.RTreePolicyStatement.resource', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6065,
  serialized_end=6149,
)


_BUILDRTREEPROOFPARAMS = _descriptor.Descriptor(
  name='BuildRTreeProofParams',
  full_name='mqpb.BuildRTreeProofParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perspective', full_name='mqpb.BuildRTreeProofParams.perspective', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectHash', full_name='mqpb.BuildRTreeProofParams.subjectHash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='mqpb.BuildRTreeProofParams.namespace', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statements', full_name='mqpb.BuildRTreeProofParams.statements', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resyncFirst', full_name='mqpb.BuildRTreeProofParams.resyncFirst', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6152,
  serialized_end=6324,
)


_BUILDRTREEPROOFRESPONSE = _descriptor.Descriptor(
  name='BuildRTreeProofResponse',
  full_name='mqpb.BuildRTreeProofResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.BuildRTreeProofResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='mqpb.BuildRTreeProofResponse.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proofDER', full_name='mqpb.BuildRTreeProofResponse.proofDER', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6326,
  serialized_end=6426,
)


_VERIFYPROOFPARAMS = _descriptor.Descriptor(
  name='VerifyProofParams',
  full_name='mqpb.VerifyProofParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proofDER', full_name='mqpb.VerifyProofParams.proofDER', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requiredRTreePolicy', full_name='mqpb.VerifyProofParams.requiredRTreePolicy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6428,
  serialized_end=6513,
)


_VERIFYPROOFRESPONSE = _descriptor.Descriptor(
  name='VerifyProofResponse',
  full_name='mqpb.VerifyProofResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mqpb.VerifyProofResponse.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='mqpb.VerifyProofResponse.result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6515,
  serialized_end=6593,
)


_PROOF = _descriptor.Descriptor(
  name='Proof',
  full_name='mqpb.Proof',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='mqpb.Proof.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paths', full_name='mqpb.Proof.paths', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy', full_name='mqpb.Proof.policy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='mqpb.Proof.expiry', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='mqpb.Proof.subject', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subjectLocation', full_name='mqpb.Proof.subjectLocation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6596,
  serialized_end=6776,
)


_PROOFPATH = _descriptor.Descriptor(
  name='ProofPath',
  full_name='mqpb.ProofPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='mqpb.ProofPath.elements', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6778,
  serialized_end=6807,
)

_COMPACTPROOFRESPONSE.fields_by_name['error'].message_type = _ERROR
_REVOKEPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_REVOKERESPONSE.fields_by_name['error'].message_type = _ERROR
_RESOLVEREVERSENAMEPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_RESOLVEREVERSENAMERESPONSE.fields_by_name['error'].message_type = _ERROR
_MARKENTITYINTERESTINGPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_MARKENTITYINTERESTINGPARAMS.fields_by_name['entityLocation'].message_type = _LOCATION
_MARKENTITYINTERESTINGRESPONSE.fields_by_name['error'].message_type = _ERROR
_CREATENAMEDECLARATIONPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_CREATENAMEDECLARATIONPARAMS.fields_by_name['subjectLocation'].message_type = _LOCATION
_CREATENAMEDECLARATIONPARAMS.fields_by_name['namespaceLocation'].message_type = _LOCATION
_CREATENAMEDECLARATIONRESPONSE.fields_by_name['error'].message_type = _ERROR
_RESOLVENAMEPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_NAMEDECLARATION.fields_by_name['subjectLocation'].message_type = _LOCATION
_NAMEDECLARATION.fields_by_name['attesterLocation'].message_type = _LOCATION
_NAMEDECLARATION.fields_by_name['namespaceLocation'].message_type = _LOCATION
_NAMEDECLARATION.fields_by_name['validity'].message_type = _NAMEDECLARATIONVALIDITY
_RESOLVENAMERESPONSE.fields_by_name['error'].message_type = _ERROR
_RESOLVENAMERESPONSE.fields_by_name['entity'].message_type = _ENTITY
_RESOLVENAMERESPONSE.fields_by_name['derivation'].message_type = _NAMEDECLARATION
_RESOLVENAMERESPONSE.fields_by_name['location'].message_type = _LOCATION
_RESOLVEHASHPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_RESOLVEHASHRESPONSE.fields_by_name['error'].message_type = _ERROR
_RESOLVEHASHRESPONSE.fields_by_name['location'].message_type = _LOCATION
_RESOLVEHASHRESPONSE.fields_by_name['entity'].message_type = _ENTITY
_RESOLVEHASHRESPONSE.fields_by_name['attestation'].message_type = _ATTESTATION
_INSPECTRESPONSE.fields_by_name['error'].message_type = _ERROR
_INSPECTRESPONSE.fields_by_name['entity'].message_type = _ENTITY
_INSPECTRESPONSE.fields_by_name['attestation'].message_type = _ATTESTATION
_LISTLOCATIONSRESPONSE_AGENTLOCATIONSENTRY.fields_by_name['value'].message_type = _LOCATION
_LISTLOCATIONSRESPONSE_AGENTLOCATIONSENTRY.containing_type = _LISTLOCATIONSRESPONSE
_LISTLOCATIONSRESPONSE.fields_by_name['error'].message_type = _ERROR
_LISTLOCATIONSRESPONSE.fields_by_name['agentLocations'].message_type = _LISTLOCATIONSRESPONSE_AGENTLOCATIONSENTRY
_CREATEENTITYPARAMS.fields_by_name['revocationLocation'].message_type = _LOCATION
_CREATEENTITYRESPONSE.fields_by_name['error'].message_type = _ERROR
_ENTITY.fields_by_name['validity'].message_type = _ENTITYVALIDITY
_CREATEATTESTATIONPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_CREATEATTESTATIONPARAMS.fields_by_name['subjectLocation'].message_type = _LOCATION
_CREATEATTESTATIONPARAMS.fields_by_name['policy'].message_type = _POLICY
_RESYNCPERSPECTIVEGRAPHPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_RESYNCPERSPECTIVEGRAPHRESPONSE.fields_by_name['error'].message_type = _ERROR
_SYNCPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_ENCRYPTMESSAGEPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_ENCRYPTMESSAGEPARAMS.fields_by_name['subjectLocation'].message_type = _LOCATION
_ENCRYPTMESSAGEPARAMS.fields_by_name['namespaceLocation'].message_type = _LOCATION
_ENCRYPTMESSAGERESPONSE.fields_by_name['error'].message_type = _ERROR
_DECRYPTMESSAGEPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_DECRYPTMESSAGERESPONSE.fields_by_name['error'].message_type = _ERROR
_SYNCRESPONSE_STORAGESTATUSENTRY.fields_by_name['value'].message_type = _STORAGEDRIVERSTATUS
_SYNCRESPONSE_STORAGESTATUSENTRY.containing_type = _SYNCRESPONSE
_SYNCRESPONSE.fields_by_name['error'].message_type = _ERROR
_SYNCRESPONSE.fields_by_name['storageStatus'].message_type = _SYNCRESPONSE_STORAGESTATUSENTRY
_STORAGEDRIVERSTATUS_INFOENTRY.containing_type = _STORAGEDRIVERSTATUS
_STORAGEDRIVERSTATUS.fields_by_name['info'].message_type = _STORAGEDRIVERSTATUS_INFOENTRY
_CREATEATTESTATIONRESPONSE.fields_by_name['error'].message_type = _ERROR
_PUBLISHENTITYPARAMS.fields_by_name['location'].message_type = _LOCATION
_PUBLISHENTITYRESPONSE.fields_by_name['error'].message_type = _ERROR
_PUBLISHATTESTATIONRESPONSE.fields_by_name['error'].message_type = _ERROR
_ADDATTESTATIONPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_ADDATTESTATIONRESPONSE.fields_by_name['error'].message_type = _ERROR
_LOOKUPATTESTATIONSPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_LOOKUPATTESTATIONSRESPONSE.fields_by_name['error'].message_type = _ERROR
_LOOKUPATTESTATIONSRESPONSE.fields_by_name['results'].message_type = _ATTESTATION
_PERSPECTIVE.fields_by_name['entitySecret'].message_type = _ENTITYSECRET
_PERSPECTIVE.fields_by_name['location'].message_type = _LOCATION
_LOCATION.fields_by_name['locationURI'].message_type = _LOCATIONURI
_ATTESTATION.fields_by_name['body'].message_type = _ATTESTATIONBODY
_ATTESTATION.fields_by_name['subjectLocation'].message_type = _LOCATION
_ATTESTATION.fields_by_name['validity'].message_type = _ATTESTATIONVALIDITY
_ATTESTATIONBODY.fields_by_name['attesterLocation'].message_type = _LOCATION
_ATTESTATIONBODY.fields_by_name['policy'].message_type = _POLICY
_POLICY.fields_by_name['trustLevelPolicy'].message_type = _TRUSTLEVELPOLICY
_POLICY.fields_by_name['rTreePolicy'].message_type = _RTREEPOLICY
_RTREEPOLICY.fields_by_name['statements'].message_type = _RTREEPOLICYSTATEMENT
_BUILDRTREEPROOFPARAMS.fields_by_name['perspective'].message_type = _PERSPECTIVE
_BUILDRTREEPROOFPARAMS.fields_by_name['statements'].message_type = _RTREEPOLICYSTATEMENT
_BUILDRTREEPROOFRESPONSE.fields_by_name['error'].message_type = _ERROR
_BUILDRTREEPROOFRESPONSE.fields_by_name['result'].message_type = _PROOF
_VERIFYPROOFPARAMS.fields_by_name['requiredRTreePolicy'].message_type = _RTREEPOLICY
_VERIFYPROOFRESPONSE.fields_by_name['error'].message_type = _ERROR
_VERIFYPROOFRESPONSE.fields_by_name['result'].message_type = _PROOF
_PROOF.fields_by_name['elements'].message_type = _ATTESTATION
_PROOF.fields_by_name['paths'].message_type = _PROOFPATH
_PROOF.fields_by_name['policy'].message_type = _POLICY
_PROOF.fields_by_name['subjectLocation'].message_type = _LOCATION
DESCRIPTOR.message_types_by_name['CompactProofParams'] = _COMPACTPROOFPARAMS
DESCRIPTOR.message_types_by_name['CompactProofResponse'] = _COMPACTPROOFRESPONSE
DESCRIPTOR.message_types_by_name['RevokeParams'] = _REVOKEPARAMS
DESCRIPTOR.message_types_by_name['RevokeResponse'] = _REVOKERESPONSE
DESCRIPTOR.message_types_by_name['ResolveReverseNameParams'] = _RESOLVEREVERSENAMEPARAMS
DESCRIPTOR.message_types_by_name['ResolveReverseNameResponse'] = _RESOLVEREVERSENAMERESPONSE
DESCRIPTOR.message_types_by_name['MarkEntityInterestingParams'] = _MARKENTITYINTERESTINGPARAMS
DESCRIPTOR.message_types_by_name['MarkEntityInterestingResponse'] = _MARKENTITYINTERESTINGRESPONSE
DESCRIPTOR.message_types_by_name['CreateNameDeclarationParams'] = _CREATENAMEDECLARATIONPARAMS
DESCRIPTOR.message_types_by_name['CreateNameDeclarationResponse'] = _CREATENAMEDECLARATIONRESPONSE
DESCRIPTOR.message_types_by_name['ResolveNameParams'] = _RESOLVENAMEPARAMS
DESCRIPTOR.message_types_by_name['NameDeclaration'] = _NAMEDECLARATION
DESCRIPTOR.message_types_by_name['ResolveNameResponse'] = _RESOLVENAMERESPONSE
DESCRIPTOR.message_types_by_name['ResolveHashParams'] = _RESOLVEHASHPARAMS
DESCRIPTOR.message_types_by_name['ResolveHashResponse'] = _RESOLVEHASHRESPONSE
DESCRIPTOR.message_types_by_name['InspectParams'] = _INSPECTPARAMS
DESCRIPTOR.message_types_by_name['InspectResponse'] = _INSPECTRESPONSE
DESCRIPTOR.message_types_by_name['ListLocationsParams'] = _LISTLOCATIONSPARAMS
DESCRIPTOR.message_types_by_name['ListLocationsResponse'] = _LISTLOCATIONSRESPONSE
DESCRIPTOR.message_types_by_name['CreateEntityParams'] = _CREATEENTITYPARAMS
DESCRIPTOR.message_types_by_name['CreateEntityResponse'] = _CREATEENTITYRESPONSE
DESCRIPTOR.message_types_by_name['Entity'] = _ENTITY
DESCRIPTOR.message_types_by_name['CreateAttestationParams'] = _CREATEATTESTATIONPARAMS
DESCRIPTOR.message_types_by_name['ResyncPerspectiveGraphParams'] = _RESYNCPERSPECTIVEGRAPHPARAMS
DESCRIPTOR.message_types_by_name['ResyncPerspectiveGraphResponse'] = _RESYNCPERSPECTIVEGRAPHRESPONSE
DESCRIPTOR.message_types_by_name['SyncParams'] = _SYNCPARAMS
DESCRIPTOR.message_types_by_name['EncryptMessageParams'] = _ENCRYPTMESSAGEPARAMS
DESCRIPTOR.message_types_by_name['EncryptMessageResponse'] = _ENCRYPTMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['DecryptMessageParams'] = _DECRYPTMESSAGEPARAMS
DESCRIPTOR.message_types_by_name['DecryptMessageResponse'] = _DECRYPTMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['SyncResponse'] = _SYNCRESPONSE
DESCRIPTOR.message_types_by_name['StorageDriverStatus'] = _STORAGEDRIVERSTATUS
DESCRIPTOR.message_types_by_name['CreateAttestationResponse'] = _CREATEATTESTATIONRESPONSE
DESCRIPTOR.message_types_by_name['PublishEntityParams'] = _PUBLISHENTITYPARAMS
DESCRIPTOR.message_types_by_name['PublishEntityResponse'] = _PUBLISHENTITYRESPONSE
DESCRIPTOR.message_types_by_name['PublishAttestationParams'] = _PUBLISHATTESTATIONPARAMS
DESCRIPTOR.message_types_by_name['PublishAttestationResponse'] = _PUBLISHATTESTATIONRESPONSE
DESCRIPTOR.message_types_by_name['AddAttestationParams'] = _ADDATTESTATIONPARAMS
DESCRIPTOR.message_types_by_name['AddAttestationResponse'] = _ADDATTESTATIONRESPONSE
DESCRIPTOR.message_types_by_name['LookupAttestationsParams'] = _LOOKUPATTESTATIONSPARAMS
DESCRIPTOR.message_types_by_name['LookupAttestationsResponse'] = _LOOKUPATTESTATIONSRESPONSE
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['Perspective'] = _PERSPECTIVE
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
DESCRIPTOR.message_types_by_name['LocationURI'] = _LOCATIONURI
DESCRIPTOR.message_types_by_name['EntitySecret'] = _ENTITYSECRET
DESCRIPTOR.message_types_by_name['Attestation'] = _ATTESTATION
DESCRIPTOR.message_types_by_name['AttestationBody'] = _ATTESTATIONBODY
DESCRIPTOR.message_types_by_name['AttestationValidity'] = _ATTESTATIONVALIDITY
DESCRIPTOR.message_types_by_name['EntityValidity'] = _ENTITYVALIDITY
DESCRIPTOR.message_types_by_name['NameDeclarationValidity'] = _NAMEDECLARATIONVALIDITY
DESCRIPTOR.message_types_by_name['Policy'] = _POLICY
DESCRIPTOR.message_types_by_name['TrustLevelPolicy'] = _TRUSTLEVELPOLICY
DESCRIPTOR.message_types_by_name['RTreePolicy'] = _RTREEPOLICY
DESCRIPTOR.message_types_by_name['RTreePolicyStatement'] = _RTREEPOLICYSTATEMENT
DESCRIPTOR.message_types_by_name['BuildRTreeProofParams'] = _BUILDRTREEPROOFPARAMS
DESCRIPTOR.message_types_by_name['BuildRTreeProofResponse'] = _BUILDRTREEPROOFRESPONSE
DESCRIPTOR.message_types_by_name['VerifyProofParams'] = _VERIFYPROOFPARAMS
DESCRIPTOR.message_types_by_name['VerifyProofResponse'] = _VERIFYPROOFRESPONSE
DESCRIPTOR.message_types_by_name['Proof'] = _PROOF
DESCRIPTOR.message_types_by_name['ProofPath'] = _PROOFPATH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CompactProofParams = _reflection.GeneratedProtocolMessageType('CompactProofParams', (_message.Message,), dict(
  DESCRIPTOR = _COMPACTPROOFPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.CompactProofParams)
  ))
_sym_db.RegisterMessage(CompactProofParams)

CompactProofResponse = _reflection.GeneratedProtocolMessageType('CompactProofResponse', (_message.Message,), dict(
  DESCRIPTOR = _COMPACTPROOFRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.CompactProofResponse)
  ))
_sym_db.RegisterMessage(CompactProofResponse)

RevokeParams = _reflection.GeneratedProtocolMessageType('RevokeParams', (_message.Message,), dict(
  DESCRIPTOR = _REVOKEPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.RevokeParams)
  ))
_sym_db.RegisterMessage(RevokeParams)

RevokeResponse = _reflection.GeneratedProtocolMessageType('RevokeResponse', (_message.Message,), dict(
  DESCRIPTOR = _REVOKERESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.RevokeResponse)
  ))
_sym_db.RegisterMessage(RevokeResponse)

ResolveReverseNameParams = _reflection.GeneratedProtocolMessageType('ResolveReverseNameParams', (_message.Message,), dict(
  DESCRIPTOR = _RESOLVEREVERSENAMEPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ResolveReverseNameParams)
  ))
_sym_db.RegisterMessage(ResolveReverseNameParams)

ResolveReverseNameResponse = _reflection.GeneratedProtocolMessageType('ResolveReverseNameResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESOLVEREVERSENAMERESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ResolveReverseNameResponse)
  ))
_sym_db.RegisterMessage(ResolveReverseNameResponse)

MarkEntityInterestingParams = _reflection.GeneratedProtocolMessageType('MarkEntityInterestingParams', (_message.Message,), dict(
  DESCRIPTOR = _MARKENTITYINTERESTINGPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.MarkEntityInterestingParams)
  ))
_sym_db.RegisterMessage(MarkEntityInterestingParams)

MarkEntityInterestingResponse = _reflection.GeneratedProtocolMessageType('MarkEntityInterestingResponse', (_message.Message,), dict(
  DESCRIPTOR = _MARKENTITYINTERESTINGRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.MarkEntityInterestingResponse)
  ))
_sym_db.RegisterMessage(MarkEntityInterestingResponse)

CreateNameDeclarationParams = _reflection.GeneratedProtocolMessageType('CreateNameDeclarationParams', (_message.Message,), dict(
  DESCRIPTOR = _CREATENAMEDECLARATIONPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.CreateNameDeclarationParams)
  ))
_sym_db.RegisterMessage(CreateNameDeclarationParams)

CreateNameDeclarationResponse = _reflection.GeneratedProtocolMessageType('CreateNameDeclarationResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATENAMEDECLARATIONRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.CreateNameDeclarationResponse)
  ))
_sym_db.RegisterMessage(CreateNameDeclarationResponse)

ResolveNameParams = _reflection.GeneratedProtocolMessageType('ResolveNameParams', (_message.Message,), dict(
  DESCRIPTOR = _RESOLVENAMEPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ResolveNameParams)
  ))
_sym_db.RegisterMessage(ResolveNameParams)

NameDeclaration = _reflection.GeneratedProtocolMessageType('NameDeclaration', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDECLARATION,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.NameDeclaration)
  ))
_sym_db.RegisterMessage(NameDeclaration)

ResolveNameResponse = _reflection.GeneratedProtocolMessageType('ResolveNameResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESOLVENAMERESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ResolveNameResponse)
  ))
_sym_db.RegisterMessage(ResolveNameResponse)

ResolveHashParams = _reflection.GeneratedProtocolMessageType('ResolveHashParams', (_message.Message,), dict(
  DESCRIPTOR = _RESOLVEHASHPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ResolveHashParams)
  ))
_sym_db.RegisterMessage(ResolveHashParams)

ResolveHashResponse = _reflection.GeneratedProtocolMessageType('ResolveHashResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESOLVEHASHRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ResolveHashResponse)
  ))
_sym_db.RegisterMessage(ResolveHashResponse)

InspectParams = _reflection.GeneratedProtocolMessageType('InspectParams', (_message.Message,), dict(
  DESCRIPTOR = _INSPECTPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.InspectParams)
  ))
_sym_db.RegisterMessage(InspectParams)

InspectResponse = _reflection.GeneratedProtocolMessageType('InspectResponse', (_message.Message,), dict(
  DESCRIPTOR = _INSPECTRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.InspectResponse)
  ))
_sym_db.RegisterMessage(InspectResponse)

ListLocationsParams = _reflection.GeneratedProtocolMessageType('ListLocationsParams', (_message.Message,), dict(
  DESCRIPTOR = _LISTLOCATIONSPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ListLocationsParams)
  ))
_sym_db.RegisterMessage(ListLocationsParams)

ListLocationsResponse = _reflection.GeneratedProtocolMessageType('ListLocationsResponse', (_message.Message,), dict(

  AgentLocationsEntry = _reflection.GeneratedProtocolMessageType('AgentLocationsEntry', (_message.Message,), dict(
    DESCRIPTOR = _LISTLOCATIONSRESPONSE_AGENTLOCATIONSENTRY,
    __module__ = 'eapi_pb2'
    # @@protoc_insertion_point(class_scope:mqpb.ListLocationsResponse.AgentLocationsEntry)
    ))
  ,
  DESCRIPTOR = _LISTLOCATIONSRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ListLocationsResponse)
  ))
_sym_db.RegisterMessage(ListLocationsResponse)
_sym_db.RegisterMessage(ListLocationsResponse.AgentLocationsEntry)

CreateEntityParams = _reflection.GeneratedProtocolMessageType('CreateEntityParams', (_message.Message,), dict(
  DESCRIPTOR = _CREATEENTITYPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.CreateEntityParams)
  ))
_sym_db.RegisterMessage(CreateEntityParams)

CreateEntityResponse = _reflection.GeneratedProtocolMessageType('CreateEntityResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATEENTITYRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.CreateEntityResponse)
  ))
_sym_db.RegisterMessage(CreateEntityResponse)

Entity = _reflection.GeneratedProtocolMessageType('Entity', (_message.Message,), dict(
  DESCRIPTOR = _ENTITY,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.Entity)
  ))
_sym_db.RegisterMessage(Entity)

CreateAttestationParams = _reflection.GeneratedProtocolMessageType('CreateAttestationParams', (_message.Message,), dict(
  DESCRIPTOR = _CREATEATTESTATIONPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.CreateAttestationParams)
  ))
_sym_db.RegisterMessage(CreateAttestationParams)

ResyncPerspectiveGraphParams = _reflection.GeneratedProtocolMessageType('ResyncPerspectiveGraphParams', (_message.Message,), dict(
  DESCRIPTOR = _RESYNCPERSPECTIVEGRAPHPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ResyncPerspectiveGraphParams)
  ))
_sym_db.RegisterMessage(ResyncPerspectiveGraphParams)

ResyncPerspectiveGraphResponse = _reflection.GeneratedProtocolMessageType('ResyncPerspectiveGraphResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESYNCPERSPECTIVEGRAPHRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ResyncPerspectiveGraphResponse)
  ))
_sym_db.RegisterMessage(ResyncPerspectiveGraphResponse)

SyncParams = _reflection.GeneratedProtocolMessageType('SyncParams', (_message.Message,), dict(
  DESCRIPTOR = _SYNCPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.SyncParams)
  ))
_sym_db.RegisterMessage(SyncParams)

EncryptMessageParams = _reflection.GeneratedProtocolMessageType('EncryptMessageParams', (_message.Message,), dict(
  DESCRIPTOR = _ENCRYPTMESSAGEPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.EncryptMessageParams)
  ))
_sym_db.RegisterMessage(EncryptMessageParams)

EncryptMessageResponse = _reflection.GeneratedProtocolMessageType('EncryptMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _ENCRYPTMESSAGERESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.EncryptMessageResponse)
  ))
_sym_db.RegisterMessage(EncryptMessageResponse)

DecryptMessageParams = _reflection.GeneratedProtocolMessageType('DecryptMessageParams', (_message.Message,), dict(
  DESCRIPTOR = _DECRYPTMESSAGEPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.DecryptMessageParams)
  ))
_sym_db.RegisterMessage(DecryptMessageParams)

DecryptMessageResponse = _reflection.GeneratedProtocolMessageType('DecryptMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _DECRYPTMESSAGERESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.DecryptMessageResponse)
  ))
_sym_db.RegisterMessage(DecryptMessageResponse)

SyncResponse = _reflection.GeneratedProtocolMessageType('SyncResponse', (_message.Message,), dict(

  StorageStatusEntry = _reflection.GeneratedProtocolMessageType('StorageStatusEntry', (_message.Message,), dict(
    DESCRIPTOR = _SYNCRESPONSE_STORAGESTATUSENTRY,
    __module__ = 'eapi_pb2'
    # @@protoc_insertion_point(class_scope:mqpb.SyncResponse.StorageStatusEntry)
    ))
  ,
  DESCRIPTOR = _SYNCRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.SyncResponse)
  ))
_sym_db.RegisterMessage(SyncResponse)
_sym_db.RegisterMessage(SyncResponse.StorageStatusEntry)

StorageDriverStatus = _reflection.GeneratedProtocolMessageType('StorageDriverStatus', (_message.Message,), dict(

  InfoEntry = _reflection.GeneratedProtocolMessageType('InfoEntry', (_message.Message,), dict(
    DESCRIPTOR = _STORAGEDRIVERSTATUS_INFOENTRY,
    __module__ = 'eapi_pb2'
    # @@protoc_insertion_point(class_scope:mqpb.StorageDriverStatus.InfoEntry)
    ))
  ,
  DESCRIPTOR = _STORAGEDRIVERSTATUS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.StorageDriverStatus)
  ))
_sym_db.RegisterMessage(StorageDriverStatus)
_sym_db.RegisterMessage(StorageDriverStatus.InfoEntry)

CreateAttestationResponse = _reflection.GeneratedProtocolMessageType('CreateAttestationResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATEATTESTATIONRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.CreateAttestationResponse)
  ))
_sym_db.RegisterMessage(CreateAttestationResponse)

PublishEntityParams = _reflection.GeneratedProtocolMessageType('PublishEntityParams', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHENTITYPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PublishEntityParams)
  ))
_sym_db.RegisterMessage(PublishEntityParams)

PublishEntityResponse = _reflection.GeneratedProtocolMessageType('PublishEntityResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHENTITYRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PublishEntityResponse)
  ))
_sym_db.RegisterMessage(PublishEntityResponse)

PublishAttestationParams = _reflection.GeneratedProtocolMessageType('PublishAttestationParams', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHATTESTATIONPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PublishAttestationParams)
  ))
_sym_db.RegisterMessage(PublishAttestationParams)

PublishAttestationResponse = _reflection.GeneratedProtocolMessageType('PublishAttestationResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHATTESTATIONRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.PublishAttestationResponse)
  ))
_sym_db.RegisterMessage(PublishAttestationResponse)

AddAttestationParams = _reflection.GeneratedProtocolMessageType('AddAttestationParams', (_message.Message,), dict(
  DESCRIPTOR = _ADDATTESTATIONPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.AddAttestationParams)
  ))
_sym_db.RegisterMessage(AddAttestationParams)

AddAttestationResponse = _reflection.GeneratedProtocolMessageType('AddAttestationResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDATTESTATIONRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.AddAttestationResponse)
  ))
_sym_db.RegisterMessage(AddAttestationResponse)

LookupAttestationsParams = _reflection.GeneratedProtocolMessageType('LookupAttestationsParams', (_message.Message,), dict(
  DESCRIPTOR = _LOOKUPATTESTATIONSPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.LookupAttestationsParams)
  ))
_sym_db.RegisterMessage(LookupAttestationsParams)

LookupAttestationsResponse = _reflection.GeneratedProtocolMessageType('LookupAttestationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LOOKUPATTESTATIONSRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.LookupAttestationsResponse)
  ))
_sym_db.RegisterMessage(LookupAttestationsResponse)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.Error)
  ))
_sym_db.RegisterMessage(Error)

Perspective = _reflection.GeneratedProtocolMessageType('Perspective', (_message.Message,), dict(
  DESCRIPTOR = _PERSPECTIVE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.Perspective)
  ))
_sym_db.RegisterMessage(Perspective)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), dict(
  DESCRIPTOR = _LOCATION,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.Location)
  ))
_sym_db.RegisterMessage(Location)

LocationURI = _reflection.GeneratedProtocolMessageType('LocationURI', (_message.Message,), dict(
  DESCRIPTOR = _LOCATIONURI,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.LocationURI)
  ))
_sym_db.RegisterMessage(LocationURI)

EntitySecret = _reflection.GeneratedProtocolMessageType('EntitySecret', (_message.Message,), dict(
  DESCRIPTOR = _ENTITYSECRET,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.EntitySecret)
  ))
_sym_db.RegisterMessage(EntitySecret)

Attestation = _reflection.GeneratedProtocolMessageType('Attestation', (_message.Message,), dict(
  DESCRIPTOR = _ATTESTATION,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.Attestation)
  ))
_sym_db.RegisterMessage(Attestation)

AttestationBody = _reflection.GeneratedProtocolMessageType('AttestationBody', (_message.Message,), dict(
  DESCRIPTOR = _ATTESTATIONBODY,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.AttestationBody)
  ))
_sym_db.RegisterMessage(AttestationBody)

AttestationValidity = _reflection.GeneratedProtocolMessageType('AttestationValidity', (_message.Message,), dict(
  DESCRIPTOR = _ATTESTATIONVALIDITY,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.AttestationValidity)
  ))
_sym_db.RegisterMessage(AttestationValidity)

EntityValidity = _reflection.GeneratedProtocolMessageType('EntityValidity', (_message.Message,), dict(
  DESCRIPTOR = _ENTITYVALIDITY,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.EntityValidity)
  ))
_sym_db.RegisterMessage(EntityValidity)

NameDeclarationValidity = _reflection.GeneratedProtocolMessageType('NameDeclarationValidity', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDECLARATIONVALIDITY,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.NameDeclarationValidity)
  ))
_sym_db.RegisterMessage(NameDeclarationValidity)

Policy = _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), dict(
  DESCRIPTOR = _POLICY,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.Policy)
  ))
_sym_db.RegisterMessage(Policy)

TrustLevelPolicy = _reflection.GeneratedProtocolMessageType('TrustLevelPolicy', (_message.Message,), dict(
  DESCRIPTOR = _TRUSTLEVELPOLICY,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.TrustLevelPolicy)
  ))
_sym_db.RegisterMessage(TrustLevelPolicy)

RTreePolicy = _reflection.GeneratedProtocolMessageType('RTreePolicy', (_message.Message,), dict(
  DESCRIPTOR = _RTREEPOLICY,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.RTreePolicy)
  ))
_sym_db.RegisterMessage(RTreePolicy)

RTreePolicyStatement = _reflection.GeneratedProtocolMessageType('RTreePolicyStatement', (_message.Message,), dict(
  DESCRIPTOR = _RTREEPOLICYSTATEMENT,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.RTreePolicyStatement)
  ))
_sym_db.RegisterMessage(RTreePolicyStatement)

BuildRTreeProofParams = _reflection.GeneratedProtocolMessageType('BuildRTreeProofParams', (_message.Message,), dict(
  DESCRIPTOR = _BUILDRTREEPROOFPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.BuildRTreeProofParams)
  ))
_sym_db.RegisterMessage(BuildRTreeProofParams)

BuildRTreeProofResponse = _reflection.GeneratedProtocolMessageType('BuildRTreeProofResponse', (_message.Message,), dict(
  DESCRIPTOR = _BUILDRTREEPROOFRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.BuildRTreeProofResponse)
  ))
_sym_db.RegisterMessage(BuildRTreeProofResponse)

VerifyProofParams = _reflection.GeneratedProtocolMessageType('VerifyProofParams', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYPROOFPARAMS,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.VerifyProofParams)
  ))
_sym_db.RegisterMessage(VerifyProofParams)

VerifyProofResponse = _reflection.GeneratedProtocolMessageType('VerifyProofResponse', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYPROOFRESPONSE,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.VerifyProofResponse)
  ))
_sym_db.RegisterMessage(VerifyProofResponse)

Proof = _reflection.GeneratedProtocolMessageType('Proof', (_message.Message,), dict(
  DESCRIPTOR = _PROOF,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.Proof)
  ))
_sym_db.RegisterMessage(Proof)

ProofPath = _reflection.GeneratedProtocolMessageType('ProofPath', (_message.Message,), dict(
  DESCRIPTOR = _PROOFPATH,
  __module__ = 'eapi_pb2'
  # @@protoc_insertion_point(class_scope:mqpb.ProofPath)
  ))
_sym_db.RegisterMessage(ProofPath)


_LISTLOCATIONSRESPONSE_AGENTLOCATIONSENTRY._options = None
_SYNCRESPONSE_STORAGESTATUSENTRY._options = None
_STORAGEDRIVERSTATUS_INFOENTRY._options = None

_WAVE = _descriptor.ServiceDescriptor(
  name='WAVE',
  full_name='mqpb.WAVE',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=6810,
  serialized_end=9132,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateEntity',
    full_name='mqpb.WAVE.CreateEntity',
    index=0,
    containing_service=None,
    input_type=_CREATEENTITYPARAMS,
    output_type=_CREATEENTITYRESPONSE,
    serialized_options=_b('\202\323\344\223\002\025\"\020/v1/CreateEntity:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateAttestation',
    full_name='mqpb.WAVE.CreateAttestation',
    index=1,
    containing_service=None,
    input_type=_CREATEATTESTATIONPARAMS,
    output_type=_CREATEATTESTATIONRESPONSE,
    serialized_options=_b('\202\323\344\223\002\032\"\025/v1/CreateAttestation:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='PublishEntity',
    full_name='mqpb.WAVE.PublishEntity',
    index=2,
    containing_service=None,
    input_type=_PUBLISHENTITYPARAMS,
    output_type=_PUBLISHENTITYRESPONSE,
    serialized_options=_b('\202\323\344\223\002\026\"\021/v1/PublishEntity:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='PublishAttestation',
    full_name='mqpb.WAVE.PublishAttestation',
    index=3,
    containing_service=None,
    input_type=_PUBLISHATTESTATIONPARAMS,
    output_type=_PUBLISHATTESTATIONRESPONSE,
    serialized_options=_b('\202\323\344\223\002\033\"\026/v1/PublishAttestation:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='AddAttestation',
    full_name='mqpb.WAVE.AddAttestation',
    index=4,
    containing_service=None,
    input_type=_ADDATTESTATIONPARAMS,
    output_type=_ADDATTESTATIONRESPONSE,
    serialized_options=_b('\202\323\344\223\002\027\"\022/v1/AddAttestation:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='LookupAttestations',
    full_name='mqpb.WAVE.LookupAttestations',
    index=5,
    containing_service=None,
    input_type=_LOOKUPATTESTATIONSPARAMS,
    output_type=_LOOKUPATTESTATIONSRESPONSE,
    serialized_options=_b('\202\323\344\223\002\032\"\025/v1/LookupAttestation:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ResyncPerspectiveGraph',
    full_name='mqpb.WAVE.ResyncPerspectiveGraph',
    index=6,
    containing_service=None,
    input_type=_RESYNCPERSPECTIVEGRAPHPARAMS,
    output_type=_RESYNCPERSPECTIVEGRAPHRESPONSE,
    serialized_options=_b('\202\323\344\223\002\037\"\032/v1/ResyncPerspectiveGraph:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='SyncStatus',
    full_name='mqpb.WAVE.SyncStatus',
    index=7,
    containing_service=None,
    input_type=_SYNCPARAMS,
    output_type=_SYNCRESPONSE,
    serialized_options=_b('\202\323\344\223\002\023\"\016/v1/SyncStatus:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='WaitForSyncComplete',
    full_name='mqpb.WAVE.WaitForSyncComplete',
    index=8,
    containing_service=None,
    input_type=_SYNCPARAMS,
    output_type=_SYNCRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='BuildRTreeProof',
    full_name='mqpb.WAVE.BuildRTreeProof',
    index=9,
    containing_service=None,
    input_type=_BUILDRTREEPROOFPARAMS,
    output_type=_BUILDRTREEPROOFRESPONSE,
    serialized_options=_b('\202\323\344\223\002\030\"\023/v1/BuildRTreeProof:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='VerifyProof',
    full_name='mqpb.WAVE.VerifyProof',
    index=10,
    containing_service=None,
    input_type=_VERIFYPROOFPARAMS,
    output_type=_VERIFYPROOFRESPONSE,
    serialized_options=_b('\202\323\344\223\002\024\"\017/v1/VerifyProof:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ListLocations',
    full_name='mqpb.WAVE.ListLocations',
    index=11,
    containing_service=None,
    input_type=_LISTLOCATIONSPARAMS,
    output_type=_LISTLOCATIONSRESPONSE,
    serialized_options=_b('\202\323\344\223\002\026\"\021/v1/ListLocations:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='Inspect',
    full_name='mqpb.WAVE.Inspect',
    index=12,
    containing_service=None,
    input_type=_INSPECTPARAMS,
    output_type=_INSPECTRESPONSE,
    serialized_options=_b('\202\323\344\223\002\020\"\013/v1/Inspect:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ResolveHash',
    full_name='mqpb.WAVE.ResolveHash',
    index=13,
    containing_service=None,
    input_type=_RESOLVEHASHPARAMS,
    output_type=_RESOLVEHASHRESPONSE,
    serialized_options=_b('\202\323\344\223\002\024\"\017/v1/ResolveHash:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EncryptMessage',
    full_name='mqpb.WAVE.EncryptMessage',
    index=14,
    containing_service=None,
    input_type=_ENCRYPTMESSAGEPARAMS,
    output_type=_ENCRYPTMESSAGERESPONSE,
    serialized_options=_b('\202\323\344\223\002\027\"\022/v1/EncryptMessage:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DecryptMessage',
    full_name='mqpb.WAVE.DecryptMessage',
    index=15,
    containing_service=None,
    input_type=_DECRYPTMESSAGEPARAMS,
    output_type=_DECRYPTMESSAGERESPONSE,
    serialized_options=_b('\202\323\344\223\002\027\"\022/v1/DecryptMessage:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateNameDeclaration',
    full_name='mqpb.WAVE.CreateNameDeclaration',
    index=16,
    containing_service=None,
    input_type=_CREATENAMEDECLARATIONPARAMS,
    output_type=_CREATENAMEDECLARATIONRESPONSE,
    serialized_options=_b('\202\323\344\223\002\036\"\031/v1/CreateNameDeclaration:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ResolveName',
    full_name='mqpb.WAVE.ResolveName',
    index=17,
    containing_service=None,
    input_type=_RESOLVENAMEPARAMS,
    output_type=_RESOLVENAMERESPONSE,
    serialized_options=_b('\202\323\344\223\002\024\"\017/v1/ResolveName:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='MarkEntityInteresting',
    full_name='mqpb.WAVE.MarkEntityInteresting',
    index=18,
    containing_service=None,
    input_type=_MARKENTITYINTERESTINGPARAMS,
    output_type=_MARKENTITYINTERESTINGRESPONSE,
    serialized_options=_b('\202\323\344\223\002\036\"\031/v1/MarkEntityInteresting:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ResolveReverseName',
    full_name='mqpb.WAVE.ResolveReverseName',
    index=19,
    containing_service=None,
    input_type=_RESOLVEREVERSENAMEPARAMS,
    output_type=_RESOLVEREVERSENAMERESPONSE,
    serialized_options=_b('\202\323\344\223\002\033\"\026/v1/ResolveReverseName:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='Revoke',
    full_name='mqpb.WAVE.Revoke',
    index=20,
    containing_service=None,
    input_type=_REVOKEPARAMS,
    output_type=_REVOKERESPONSE,
    serialized_options=_b('\202\323\344\223\002\017\"\n/v1/Revoke:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CompactProof',
    full_name='mqpb.WAVE.CompactProof',
    index=21,
    containing_service=None,
    input_type=_COMPACTPROOFPARAMS,
    output_type=_COMPACTPROOFRESPONSE,
    serialized_options=_b('\202\323\344\223\002\025\"\020/v1/CompactProof:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_WAVE)

DESCRIPTOR.services_by_name['WAVE'] = _WAVE

# @@protoc_insertion_point(module_scope)
